
-   ![](https://github.com/adafruit.png?size=40){ width="40" loading=lazy align=left } adafruit

    ---

    ??? example "Examples"
        - adafruit/circuitpython#9785


-   ![](https://github.com/apache.png?size=40){ width="40" loading=lazy align=left } apache

    ---

    ??? example "Examples"
        - apache/airflow#45408
        - apache/opennlp#736


-   ![](https://github.com/ashishb.png?size=40){ width="40" loading=lazy align=left } ashishb

    ---

    ??? example "Examples"
        - ashishb/wp2hugo#91


-   ![](https://github.com/astral-sh.png?size=40){ width="40" loading=lazy align=left } astral-sh

    ---

    ??? example "Examples"
        - astral-sh/ruff#14844


-   ![](https://github.com/astropy.png?size=40){ width="40" loading=lazy align=left } astropy

    ---

    ??? example "Examples"
        - astropy/astropy#17315


-   ![](https://github.com/autotag-dev.png?size=40){ width="40" loading=lazy align=left } autotag-dev

    ---

    ??? example "Examples"
        - autotag-dev/autotag#142


-   ![](https://github.com/blakeblackshear.png?size=40){ width="40" loading=lazy align=left } blakeblackshear

    ---

    ??? example "Examples"
        - blakeblackshear/frigate#15490


-   ![](https://github.com/brian-team.png?size=40){ width="40" loading=lazy align=left } brian-team

    ---

    ??? example "Examples"
        - brian-team/brian2@d497b11a268549c0c491df2f5f9c6332c4f733d0


-   ![](https://github.com/cakephp.png?size=40){ width="40" loading=lazy align=left } cakephp

    ---

    ??? example "Examples"
        - cakephp/cakephp#18081


-   ![](https://github.com/curl.png?size=40){ width="40" loading=lazy align=left } curl

    ---

    ??? example "Examples"
        - curl/curl@ba9fe58d4331402a24495618668b2cc8afe9794e
        - curl/curl-for-win@05ca7551743b936656033352be0d796cf56e5c0c


-   ![](https://github.com/danmar.png?size=40){ width="40" loading=lazy align=left } danmar

    ---

    ??? example "Examples"
        - danmar/cppcheck#7044


-   ![](https://github.com/DataDog.png?size=40){ width="40" loading=lazy align=left } DataDog

    ---

    ??? example "Examples"
        - DataDog/datadog-agent#30871
        - DataDog/dd-trace-py#11640


-   ![](https://github.com/datalens-tech.png?size=40){ width="40" loading=lazy align=left } datalens-tech

    ---

    ??? example "Examples"
        - datalens-tech/datalens-backend#777


-   ![](https://github.com/Diaoul.png?size=40){ width="40" loading=lazy align=left } Diaoul

    ---

    ??? example "Examples"
        - Diaoul/subliminal#1190


-   ![](https://github.com/Electric-Coin-Company.png?size=40){ width="40" loading=lazy align=left } Electric-Coin-Company

    ---

    ??? example "Examples"
        - Electric-Coin-Company/zcash-light-client-ffi#186


-   ![](https://github.com/esl.png?size=40){ width="40" loading=lazy align=left } esl

    ---

    ??? example "Examples"
        - esl/MongooseIM#4435


-   ![](https://github.com/ethereum.png?size=40){ width="40" loading=lazy align=left } ethereum

    ---

    ??? example "Examples"
        - ethereum/hevm#615


-   ![](https://github.com/fpgmaas.png?size=40){ width="40" loading=lazy align=left } fpgmaas

    ---

    ??? example "Examples"
        - fpgmaas/deptry#972


-   ![](https://github.com/freeCodeCamp.png?size=40){ width="40" loading=lazy align=left } freeCodeCamp

    ---

    ??? example "Examples"
        - freeCodeCamp/devdocs#2386


-   ![](https://github.com/freedomofpress.png?size=40){ width="40" loading=lazy align=left } freedomofpress

    ---

    ??? example "Examples"
        - freedomofpress/securedrop-workstation#1222


-   ![](https://github.com/freemocap.png?size=40){ width="40" loading=lazy align=left } freemocap

    ---

    ??? example "Examples"
        - freemocap/freemocap#659


-   ![](https://github.com/gaphor.png?size=40){ width="40" loading=lazy align=left } gaphor

    ---

    ??? example "Examples"
        - gaphor/gaphor#3658


-   ![](https://github.com/getsops.png?size=40){ width="40" loading=lazy align=left } getsops

    ---

    ??? example "Examples"
        - getsops/sops#1704


-   ![](https://github.com/girlbossceo.png?size=40){ width="40" loading=lazy align=left } girlbossceo

    ---

    ??? example "Examples"
        - girlbossceo/conduwuit@c6bf8f5ea15a6b963220a1de4bb50a639d0d0696


-   ![](https://github.com/git-lfs.png?size=40){ width="40" loading=lazy align=left } git-lfs

    ---

    ??? example "Examples"
        - git-lfs/git-lfs#5930


-   ![](https://github.com/google.png?size=40){ width="40" loading=lazy align=left } google

    ---

    ??? example "Examples"
        - google/zx#1067


-   ![](https://github.com/guacsec.png?size=40){ width="40" loading=lazy align=left } guacsec

    ---

    ??? example "Examples"
        - guacsec/guac#2276


-   ![](https://github.com/Homebrew.png?size=40){ width="40" loading=lazy align=left } Homebrew

    ---

    ??? example "Examples"
        - Homebrew/actions#630
        - Homebrew/actions#631
        - Homebrew/brew#18662
        - Homebrew/brew.sh#1107
        - Homebrew/formulae.brew.sh#1621
        - Homebrew/homebrew-cask#195318
        - Homebrew/homebrew-cask#195310
        - Homebrew/homebrew-cask#195309
        - Homebrew/homebrew-cask#195308
        - Homebrew/homebrew-command-not-found#203
        - Homebrew/homebrew-core#195961
        - Homebrew/homebrew-core#201306
        - Homebrew/homebrew-portable-ruby#255


-   ![](https://github.com/huggingface.png?size=40){ width="40" loading=lazy align=left } huggingface

    ---

    ??? example "Examples"
        - huggingface/peft#2288


-   ![](https://github.com/hugovk.png?size=40){ width="40" loading=lazy align=left } hugovk

    ---

    ??? example "Examples"
        - hugovk/em-keyboard#148
        - hugovk/norwegianblue#233
        - hugovk/pypistats#460


-   ![](https://github.com/hynek.png?size=40){ width="40" loading=lazy align=left } hynek

    ---

    ??? example "Examples"
        - hynek/argon2-cffi#185
        - hynek/doc2dash#225
        - hynek/environ-config#88
        - hynek/hatch-fancy-pypi-readme#57
        - hynek/pem#100
        - hynek/prometheus-async#70
        - hynek/stamina#81
        - hynek/structlog#663
        - hynek/svcs#111


-   ![](https://github.com/icsharpcode.png?size=40){ width="40" loading=lazy align=left } icsharpcode

    ---

    ??? example "Examples"
        - icsharpcode/ILSpy#3365


-   ![](https://github.com/Instagram.png?size=40){ width="40" loading=lazy align=left } Instagram

    ---

    ??? example "Examples"
        - Instagram/LibCST#1262


-   ![](https://github.com/lmstudio-ai.png?size=40){ width="40" loading=lazy align=left } lmstudio-ai

    ---

    ??? example "Examples"
        - lmstudio-ai/venvstacks#51


-   ![](https://github.com/marcusvolz.png?size=40){ width="40" loading=lazy align=left } marcusvolz

    ---

    ??? example "Examples"
        - marcusvolz/strava_py#53


-   ![](https://github.com/matplotlib.png?size=40){ width="40" loading=lazy align=left } matplotlib

    ---

    ??? example "Examples"
        - matplotlib/matplotlib#29251


-   ![](https://github.com/maxmind.png?size=40){ width="40" loading=lazy align=left } maxmind

    ---

    ??? example "Examples"
        - maxmind/mmdbinspect#82
        - maxmind/MaxMind-DB-Reader-python#178
        - maxmind/GeoIP2-php#233
        - maxmind/MaxMind-DB-Reader-dotnet#198
        - maxmind/libmaxminddb#365
        - maxmind/GeoIP2-java#517
        - maxmind/MaxMind-DB-Reader-java#221
        - maxmind/geoipupdate#354
        - maxmind/geoip2-csv-converter#87
        - maxmind/mmdbwriter#104
        - maxmind/GeoIP2-node#1387


-   ![](https://github.com/mfussenegger.png?size=40){ width="40" loading=lazy align=left } mfussenegger

    ---

    ??? example "Examples"
        - mfussenegger/nvim-lint#710


-   ![](https://github.com/mkuf.png?size=40){ width="40" loading=lazy align=left } mkuf

    ---

    ??? example "Examples"
        - mkuf/prind#183


-   ![](https://github.com/mne-tools.png?size=40){ width="40" loading=lazy align=left } mne-tools

    ---

    ??? example "Examples"
        - mne-tools/mne-python#13011


-   ![](https://github.com/MoarVM.png?size=40){ width="40" loading=lazy align=left } MoarVM

    ---

    ??? example "Examples"
        - MoarVM/MoarVM#1875


-   ![](https://github.com/mongodb.png?size=40){ width="40" loading=lazy align=left } mongodb

    ---

    ??? example "Examples"
        - mongodb/motor#312
        - mongodb/mongo-python-driver#2001


-   ![](https://github.com/narwhals-dev.png?size=40){ width="40" loading=lazy align=left } narwhals-dev

    ---

    ??? example "Examples"
        - narwhals-dev/narwhals#1567


-   ![](https://github.com/NetApp.png?size=40){ width="40" loading=lazy align=left } NetApp

    ---

    ??? example "Examples"
        - NetApp/harvest#3247


-   ![](https://github.com/nextcloud.png?size=40){ width="40" loading=lazy align=left } nextcloud

    ---

    ??? example "Examples"
        - nextcloud/.github#477


-   ![](https://github.com/NLnetLabs.png?size=40){ width="40" loading=lazy align=left } NLnetLabs

    ---

    ??? example "Examples"
        - NLnetLabs/nsd#413
        - NLnetLabs/unbound#1204


-   ![](https://github.com/numpy.png?size=40){ width="40" loading=lazy align=left } numpy

    ---

    ??? example "Examples"
        - numpy/numpy#27931
        - numpy/numpy.org#797


-   ![](https://github.com/Ouranosinc.png?size=40){ width="40" loading=lazy align=left } Ouranosinc

    ---

    ??? example "Examples"
        - Ouranosinc/xclim#2023


-   ![](https://github.com/oxc-project.png?size=40){ width="40" loading=lazy align=left } oxc-project

    ---

    ??? example "Examples"
        - oxc-project/oxc#7844


-   ![](https://github.com/praetorian-inc.png?size=40){ width="40" loading=lazy align=left } praetorian-inc

    ---

    ??? example "Examples"
        - praetorian-inc/noseyparker#228


-   ![](https://github.com/prettytable.png?size=40){ width="40" loading=lazy align=left } prettytable

    ---

    ??? example "Examples"
        - prettytable/prettytable#339


-   ![](https://github.com/psf.png?size=40){ width="40" loading=lazy align=left } psf

    ---

    ??? example "Examples"
        - psf/cachecontrol#345


-   ![](https://github.com/pyca.png?size=40){ width="40" loading=lazy align=left } pyca

    ---

    ??? example "Examples"
        - pyca/service-identity#75


-   ![](https://github.com/pylast.png?size=40){ width="40" loading=lazy align=left } pylast

    ---

    ??? example "Examples"
        - pylast/pylast#465


-   ![](https://github.com/PyO3.png?size=40){ width="40" loading=lazy align=left } PyO3

    ---

    ??? example "Examples"
        - PyO3/pyo3#4774


-   ![](https://github.com/pypa.png?size=40){ width="40" loading=lazy align=left } pypa

    ---

    ??? example "Examples"
        - pypa/packaging.python.org#1765
        - pypa/pip-audit#851


-   ![](https://github.com/pypi.png?size=40){ width="40" loading=lazy align=left } pypi

    ---

    ??? example "Examples"
        - pypi/stdlib-list#138
        - pypi/warehouse#16996


-   ![](https://github.com/pytest-dev.png?size=40){ width="40" loading=lazy align=left } pytest-dev

    ---

    ??? example "Examples"
        - pytest-dev/pytest#13062


-   ![](https://github.com/python.png?size=40){ width="40" loading=lazy align=left } python

    ---

    ??? example "Examples"
        - python/bedevere#652
        - python/cpython#127749
        - python/miss-islington#705


-   ![](https://github.com/python-attrs.png?size=40){ width="40" loading=lazy align=left } python-attrs

    ---

    ??? example "Examples"
        - python-attrs/attrs#1368
        - python-attrs/cattrs#605


-   ![](https://github.com/python-humanize.png?size=40){ width="40" loading=lazy align=left } python-humanize

    ---

    ??? example "Examples"
        - python-humanize/humanize#221


-   ![](https://github.com/python-pillow.png?size=40){ width="40" loading=lazy align=left } python-pillow

    ---

    ??? example "Examples"
        - python-pillow/Pillow#8526


-   ![](https://github.com/python-poetry.png?size=40){ width="40" loading=lazy align=left } python-poetry

    ---

    ??? example "Examples"
        - python-poetry/cleo#462
        - python-poetry/poetry#9895
        - python-poetry/poetry-core#799
        - python-poetry/poetry-plugin-export#308
        - python-poetry/poetry-plugin-bundle#125


-   ![](https://github.com/python-telegram-bot.png?size=40){ width="40" loading=lazy align=left } python-telegram-bot

    ---

    ??? example "Examples"
        - python-telegram-bot/python-telegram-bot#4606


-   ![](https://github.com/python-trio.png?size=40){ width="40" loading=lazy align=left } python-trio

    ---

    ??? example "Examples"
        - python-trio/trio#3154


-   ![](https://github.com/PyVRP.png?size=40){ width="40" loading=lazy align=left } PyVRP

    ---

    ??? example "Examples"
        - PyVRP/PyVRP#670


-   ![](https://github.com/rubygems.png?size=40){ width="40" loading=lazy align=left } rubygems

    ---

    ??? example "Examples"
        - rubygems/rubygems.org#5350


-   ![](https://github.com/rust-lang.png?size=40){ width="40" loading=lazy align=left } rust-lang

    ---

    ??? example "Examples"
        - rust-lang/crates.io#10176
        - rust-lang/rust-clippy#13933


-   ![](https://github.com/rustls.png?size=40){ width="40" loading=lazy align=left } rustls

    ---

    ??? example "Examples"
        - rustls/rustls#2261
        - rustls/tokio-rustls#96
        - rustls/webpki#299


-   ![](https://github.com/Saghen.png?size=40){ width="40" loading=lazy align=left } Saghen

    ---

    ??? example "Examples"
        - Saghen/blink.cmp#991


-   ![](https://github.com/sigstore.png?size=40){ width="40" loading=lazy align=left } sigstore

    ---

    ??? example "Examples"
        - sigstore/cosign#3959
        - sigstore/gitsign#602


-   ![](https://github.com/simpeg.png?size=40){ width="40" loading=lazy align=left } simpeg

    ---

    ??? example "Examples"
        - simpeg/simpeg#1592


-   ![](https://github.com/termcolor.png?size=40){ width="40" loading=lazy align=left } termcolor

    ---

    ??? example "Examples"
        - termcolor/termcolor#89


-   ![](https://github.com/termux.png?size=40){ width="40" loading=lazy align=left } termux

    ---

    ??? example "Examples"
        - termux/termux-packages#22519


-   ![](https://github.com/torchbox.png?size=40){ width="40" loading=lazy align=left } torchbox

    ---

    ??? example "Examples"
        - torchbox/wagtailmedia#252


-   ![](https://github.com/tornadoweb.png?size=40){ width="40" loading=lazy align=left } tornadoweb

    ---

    ??? example "Examples"
        - tornadoweb/tornado#3438


-   ![](https://github.com/ua-parser.png?size=40){ width="40" loading=lazy align=left } ua-parser

    ---

    ??? example "Examples"
        - ua-parser/uap-python#250


-   ![](https://github.com/ultrajson.png?size=40){ width="40" loading=lazy align=left } ultrajson

    ---

    ??? example "Examples"
        - ultrajson/ultrajson#650


-   ![](https://github.com/Unidata.png?size=40){ width="40" loading=lazy align=left } Unidata

    ---

    ??? example "Examples"
        - Unidata/MetPy#3710


-   ![](https://github.com/urllib3.png?size=40){ width="40" loading=lazy align=left } urllib3

    ---

    ??? example "Examples"
        - urllib3/urllib3#3528


-   ![](https://github.com/uutils.png?size=40){ width="40" loading=lazy align=left } uutils

    ---

    ??? example "Examples"
        - uutils/coreutils#6973


-   ![](https://github.com/ViaVersion.png?size=40){ width="40" loading=lazy align=left } ViaVersion

    ---

    ??? example "Examples"
        - ViaVersion/ViaVersion#4315


-   ![](https://github.com/vlang.png?size=40){ width="40" loading=lazy align=left } vlang

    ---

    ??? example "Examples"
        - vlang/v#22681


-   ![](https://github.com/wagtail.png?size=40){ width="40" loading=lazy align=left } wagtail

    ---

    ??? example "Examples"
        - wagtail/wagtail-localize#843

